@@ -3,16 +3,18 @@ pub const API_VER: &str = "0";
 
 const PUBLIC_METHODS: &'static [&'static str] = &[
     "Time",
+    "SystemStatus",
     "Assets",
     "AssetPairs",
     "Ticker",
+    "OHLC",
     "Depth",
     "Trades",
     "Spread",
-    "OHLC",
 ];
 
 const PRIVATE_METHODS: &'static [&'static str] = &[
+    // User Data
     "Balance",
     "TradeBalance",
     "OpenOrders",
@@ -24,8 +26,18 @@ const PRIVATE_METHODS: &'static [&'static str] = &[
     "Ledgers",
     "QueryLedgers",
     "TradeVolume",
+    "AddExport",
+    "ExportStatus",
+    "RetrieveExport",
+    "RemoveExport",
+
+    // User Trading
     "AddOrder",
     "CancelOrder",
+    "CancellAll",
+    "CancelAllOrdersAfter",
+
+    // User Funding
     "DepositMethods",
     "DepositAddresses",
     "DepositStatus",
@@ -33,6 +45,9 @@ const PRIVATE_METHODS: &'static [&'static str] = &[
     "Withdraw",
     "WithdrawStatus",
     "WithdrawCancel",
+    "WalletTransfer",
+
+    // Websocket Auth
     "GetWebSocketsToken",
 ];
 
